---
title: <span class="badge object-type-scalar"></span> Hertz
---
# <span class="badge object-type-scalar"></span> Hertz

Time: Hertz (1/s)

## Definition

```python
# Time: Hertz (1/s)
Hertz: typing.Literal["hertz"] = "hertz"
```
